# Template.pm - Rules file for generator (IPTables Firewall Configuration).
# Created by James A. Pattie.  Copyright (c) 2001-2004, Xperience, Inc.

package PCXFireWall::Template;

use strict;
use vars qw ($AUTOLOAD @ISA @EXPORT);

require Exporter;
@ISA = qw(Exporter AutoLoader);
@EXPORT = qw();

# ****************** User Configuration Starts here ***************************
#  Only edit between "Define your rules here" and "Stop Defining your rules"
# *****************************************************************************

# void startingRules(configObj, interfaceObj, filterObj, natObj, mangleObj, proc, modulesObj, networkObj)
#   Defines the rules/actions that need to be done when the firewall is starting up.
sub startingRules
{
  my $self = shift;
  my %args = ( configObj => undef, interfaceObj => undef, filterObj => undef, natObj => undef, mangleObj => undef, proc => undef, modulesObj => undef, networkObj => undef, @_ );
  my $config = $args{configObj};
  my $filter = $args{filterObj};
  my $nat = $args{natObj};
  my $mangle = $args{mangleObj};
  my $interfaces = $args{interfaceObj};
  my $proc = $args{proc};
  my $modulesObj = $args{modulesObj};
  my $networkObj = $args{networkObj};

  # -------------------- Define your rules here -------------------------------

  # you must now define the lo interface
  $interfaces->defineInterface(name => "lo", location => "firewall", IP => "127.0.0.1", alias => "loopback");


  # -------------------- Stop Defining your rules -----------------------------
}

# void stoppingRules(configObj, interfaceObj, filterObj, natObj, mangleObj, proc, networkObj)
#   Defines the rules/actions that need to be done when the firewall is shutting down.
sub stoppingRules
{
  my $self = shift;
  my %args = ( configObj => undef, interfaceObj => undef, filterObj => undef, natObj => undef, mangleObj => undef, proc => undef, networkObj => undef, @_ );
  my $config = $args{configObj};
  my $filter = $args{filterObj};
  my $nat = $args{natObj};
  my $mangle = $args{mangleObj};
  my $interfaces = $args{interfaceObj};
  my $proc = $args{proc};
  my $networkObj = $args{networkObj};

  # -------------------- Define your rules here -------------------------------


  # -------------------- Stop Defining your rules -----------------------------
}

# void restartingRules(configObj)
#    Allows the user to specify the installPath to use if they want to
#    change it when we generate the restartfw script.
sub restartingRules
{
  my $self = shift;
  my %args = ( configObj => undef, @_ );
  my $config = $args{configObj};

  # -------------------- Define your rules here -------------------------------


  # -------------------- Stop Defining your rules -----------------------------
}

# ******************* User Configuration Ends here ****************************
# *****************************************************************************

sub new
{
  my $that = shift;
  my $class = ref($that) || $that;
  my $self = bless {}, $class;

  return $self;
}

sub AUTOLOAD
{
  my $self = shift;
  my $type = ref($self) || die "$self is not an object";
  my $name = $AUTOLOAD;
  $name =~ s/.*://;	# strip fully-qualified portion
  unless (exists $self->{$name})
  {
    die "Can't access `$name' field in object of class $type";
  }
  if (@_)
  {
    return $self->{$name} = shift;
  }
  else
  {
    return $self->{$name};
  }
}

1;
__END__

=head1 NAME

Template - The PCXFireWall Rules Module.

=head1 SYNOPSIS

  use PCXFireWall::Template;
  my $obj = PCXFireWall::Template->new;

  # define config, nat, filter, mangle, proc and modules objects.
  # call the rules system to allow the user to work with them.
  $obj->startingRules(configObj => $config, filterObj => $filter,
                      natObj => $nat, mangleObj => $mangle,
  		      interfaceObj => $interfaces, proc => $proc,
            modulesObj => $modulesObj);

  # then we open the file and have each module output its stuff.

=head1 DESCRIPTION

Template is the Module that Defines the IPTables Rules for the PCXFireWall.

=head1 FUNCTIONS

  scalar new(void)
    Creates a new instance of the PCXFireWall::Template
    object.

  void startingRules(configObj, interfaceObj, filterObj, natObj,
                     mangleObj, proc, modulesObj, networkObj)
    Defines the rules/actions that need to be done when the firewall is
    starting up.

  void stoppingRules(configObj, interfaceObj, filterObj, natObj,
                     mangleObj, proc, networkObj)
    Defines the rules/actions that need to be done when the firewall is
    shutting down.

  void restartingRules(configObj)
    Allows the user to specify the installPath to use if they want to
    change it when we generate the restartfw script.

  NOTE:  All data fields are accessible by specifying the object
         and pointing to the data member to be modified on the
         left-hand side of the assignment.
         Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

Xperience, Inc. (mailto:admin at pcxperience.com)

=head1 SEE ALSO

perl(1)

=cut
